'use strict';

var request = require('./request.js');
var fs = require('fs');
var path = require('path');
var AuthJetStore = require('passwordless-authjetstore');
var random = require('random-gen');

var loginForm = fs.readFileSync(path.join(__dirname, '../views/login.html')).toString();
var verifyForm = fs.readFileSync(path.join(__dirname, '../views/verify.html')).toString();
var appUrl = void 0,
    _store = void 0,
    ttl = 5 * 60 * 1000,
    _tokenAlgorithm = function tokenAlgorithm() {
	return random.upper(4);
};

function delivery() {
	return function (token, uid, recipient, cb) {
		var sendUrl = appUrl + '/deliver?token=' + token + '&uid=' + encodeURIComponent(uid) + '&recipient=' + recipient;
		request(sendUrl, cb);
	};
}

function init(username, password, appId) {
	if (appUrl) {
		throw new Error('password-sms has already been initialized');
	} else if (!username || !password || !appId) {
		throw new Error('password-sms must be initialized with username, password, and appId');
	} else {
		appUrl = 'https://' + username + ':' + password + '@authjet.com/api/passwordless/' + appId;
		_store = AuthJetStore(username, password, appId);
		request(appUrl + '/details', function (err, app) {
			ttl = app.minutesValid * 60 * 1000;
			_tokenAlgorithm = function tokenAlgorithm() {
				return random[app.pattern](app.length);
			};
		});
	}
}

module.exports = {
	init: init,
	delivery: delivery,
	store: function store() {
		return _store;
	},
	sendLoginForm: function sendLoginForm() {
		return function (req, res) {
			return res.send(loginForm);
		};
	},
	sendVerifyForm: function sendVerifyForm() {
		return function (req, res) {
			return res.send(verifyForm.replace('{{uid}}', req.passwordless.uidToAuth));
		};
	},
	options: function options() {
		return Object({ ttl: ttl, tokenAlgorithm: function tokenAlgorithm() {
				return _tokenAlgorithm();
			} });
	}
};